summaryrefslogtreecommitdiff
path: root/src/lib/signal_manager.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2015-11-03 21:27:26 +0000
committerCarl Hetherington <cth@carlh.net>2015-11-03 21:27:26 +0000
commitee1d68bbbfe89b3aa131d912747e5da4a746fdce (patch)
tree9536d458a2f75fd80f557f7706c954750d291fd5 /src/lib/signal_manager.h
parente40e1a777ab7b39046e8ff1928354d38bd762db5 (diff)
Various improvements in robustness / neatness of certificate download stuff.
Diffstat (limited to 'src/lib/signal_manager.h')
-rw-r--r--src/lib/signal_manager.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/signal_manager.h b/src/lib/signal_manager.h
index b8d892c41..62afacade 100644
--- a/src/lib/signal_manager.h
+++ b/src/lib/signal_manager.h
@@ -46,8 +46,8 @@ public:
/** Call this in the UI when it is idle */
size_t ui_idle () {
- /* This executes any functors that have been post()ed to _service */
- return _service.poll ();
+ /* This executes one of the functors that has been post()ed to _service */
+ return _service.poll_one ();
}
/** This should wake the UI and make it call ui_idle() */